﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class CameraController : MonoBehaviour
{
    [SerializeField] 
    private float cameraDistance = 15;

    [SerializeField] 
    private Transform finishCameraTarget;

    [SerializeField] 
    private float finishCameraSpeed = 5;

    [SerializeField] 
    private AudioClip finalAudio;

    private bool isTargetingHome;
    private bool isZoomStarted;

    public static CameraController Instance => instance;
    private static CameraController instance;

    private Camera camera;
    private AudioSource audioSource;
    
    private void Awake()
    {
        instance = this;
        camera = GetComponent<Camera>();
        audioSource = GetComponent<AudioSource>();
    }
    
    private void LateUpdate()
    {
        if (!isTargetingHome)
            transform.position = ShepardController.Instance.transform.position - transform.forward * cameraDistance;
        else
        {
            if (isZoomStarted)
                return;

            Vector3 targetPos = finishCameraTarget.position - transform.forward * cameraDistance;
            if(Vector3.Distance(transform.position,targetPos) > 1)
                transform.position = Vector3.MoveTowards(transform.position,targetPos, finishCameraSpeed * Time.deltaTime);
            else
            {
                isZoomStarted = true;
                StartCoroutine(StartZoomSequence());
            }
            
        }
    }

    private IEnumerator StartZoomSequence()
    {
        audioSource.PlayOneShot(finalAudio);
        yield return new WaitForSeconds(0.5f);
        camera.orthographicSize = 6;
        yield return new WaitForSeconds(1f);
        camera.orthographicSize = 5;
        yield return new WaitForSeconds(1f);
        camera.orthographicSize = 4;
    }

    public void InitiateFinishSequence()
    {
        isTargetingHome = true;
    }
}
