﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class LevelManager : MonoBehaviour
{
    [SerializeField]
    private float minWolfAttackInterval = 30;
    
    [SerializeField]
    private float maxWolfAttackInterval = 60;

    [SerializeField] 
    private Transform shepardTeleportPoint;
    
    [SerializeField] 
    private Transform sheepTeleportPoint;
    
    [HideInInspector]
    public float LatestWolfAttackTime;

    public static LevelManager Instance => instance;
    private static LevelManager instance;

    private void Awake()
    {
        if (instance != null && instance != this)
        {
            Destroy(gameObject);
            return;
        }

        instance = this;
        
        StartRandomAttacks();
    }
    
    private void Update()
    {
        if(Input.GetKeyDown(KeyCode.P))
        {
            ShepardController.Instance.transform.position = shepardTeleportPoint.position;
            SheepController.Instance.transform.position = sheepTeleportPoint.position;
        }
    }
    
    public void StartRandomAttacks()
    {
        StartCoroutine(OrderRandomAttack());
    }

    public void StopRandomAttacks()
    {
        StopAllCoroutines();
    }
    
    private IEnumerator OrderRandomAttack()
    {
        float randomTime = Random.Range(minWolfAttackInterval, maxWolfAttackInterval);
        yield return new WaitForSeconds(randomTime);
        if (Time.time - LatestWolfAttackTime > minWolfAttackInterval)
        {
            WolfController.Instance.StartChasing();
        }

        StartCoroutine(OrderRandomAttack());
    }
}
